public interface EntityManagerConfiguration
| Modifier and Type | Method and Description |
|---|---|
EntityInfoResolverFactory |
getEntityInfoResolverFactory()
Gets a EntityInfo factory to use when parsing the schema configuration annotated on
the
entity type |
NameConverters |
getNameConverters()
Gets the name converters to be used with the (to be) configured
EntityManager. |
SchemaConfiguration |
getSchemaConfiguration()
Gets the schema configuration to be used with the (to be) configured
EntityManager |
boolean |
useWeakCache()
Whether or not the
EntityManager should use weak references for caching |
boolean useWeakCache()
EntityManager should use weak references for cachingtrue if the entity manager should use weak references for caching.NameConverters getNameConverters()
EntityManager.null name converterSchemaConfiguration getSchemaConfiguration()
EntityManagernull schema configurationEntityInfoResolverFactory getEntityInfoResolverFactory()
entity typenull EntityInfo factoryCopyright © 2007-2014. All Rights Reserved.